<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-jqueryui?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// J
	'jqueryui_description' => 'Este plugin implementa a biblioteca complementar JQuery UI no SPIP, permitindo a criação de componentes gráficos dinâmicos: abas, drag & drop, barras de progressão...
As funcionalidades desta biblioteca estão organizadas em três categorias:
-* {{As interações}}. Podem fornecer propriedades muito interessantes a elementos HTML, como a possibilidade de agarrar e deslocar elementos com o mouse (drag & drop), redimensioná-los como se fossem janelas ou de os selecionar como ícones do seu sistema operacional.
-* {{Os Widgets}}. São objetos prontos, que oferecem funcionalidades sofisticadas como, por exemplo, o DatePicker, que exibe um calendário para seleção de uma data.
-* {{Os efeitos}}. Enriquecem os efeitos padrão oferecidos pelo JQuery (fadeIn, slideUp...). Graças ao JQuery UI é, por exemplo, possível animar a propriedade CSS background-color com .animate() ou ainda adicionar transições às ações addClass/removeClass...', # MODIF
	'jqueryui_slogan' => 'Animações, efeitos e widgets jQuery'
);

?>
